@@ -945,6 +945,9 @@ dispose(GObject *object)
 	lasso_release_string(profile->private_data->artifact_message);
 
 	G_OBJECT_CLASS(parent_class)->dispose(G_OBJECT(profile));
+
+	lasso_release_gobject(profile->private_data->idp_list);
+	lasso_release_string(profile->private_data->message_id);
 }
 
 /*****************************************************************************/
