@@ -78,11 +78,11 @@ static struct XmlSnippet schema_snippets[] = {
 		G_STRUCT_OFFSET(LassoSaml2Assertion, Advice), NULL, NULL, NULL},
 	{ "Statement", SNIPPET_LIST_NODES,
 		G_STRUCT_OFFSET(LassoSaml2Assertion, Statement), NULL, NULL, NULL},
-	{ "AuthnStatement", SNIPPET_LIST_NODES,
+	{ "AuthnStatement", SNIPPET_LIST_NODES | SNIPPET_JUMP_ON_MATCH | SNIPPET_BACK_1,
 		G_STRUCT_OFFSET(LassoSaml2Assertion, AuthnStatement), NULL, NULL, NULL},
-	{ "AuthzDecisionStatement", SNIPPET_LIST_NODES,
+	{ "AuthzDecisionStatement", SNIPPET_LIST_NODES | SNIPPET_JUMP_ON_MATCH | SNIPPET_BACK_2,
 		G_STRUCT_OFFSET(LassoSaml2Assertion, AuthzDecisionStatement), NULL, NULL, NULL},
-	{ "AttributeStatement", SNIPPET_LIST_NODES,
+	{ "AttributeStatement", SNIPPET_LIST_NODES | SNIPPET_JUMP_ON_MATCH | SNIPPET_BACK_3,
 		G_STRUCT_OFFSET(LassoSaml2Assertion, AttributeStatement), NULL, NULL, NULL},
 	{ "Version", SNIPPET_ATTRIBUTE,
 		G_STRUCT_OFFSET(LassoSaml2Assertion, Version), NULL, NULL, NULL},
